@@ -86,8 +86,14 @@ def add_info(r, item, **kwargs):
                     (kwargs["caption"], dict["story"][realitem]))\
                     + dict["content"]
 
-    add_hook_pre_reader(r, hook, before=add_info_holster)
-    add_info_holster = hook
+    if "before" in kwargs:
+        add_hook_pre_reader(r, hook, before=kwargs["before"])
+    elif "after" in kwargs:
+        add_hook_pre_reader(r, hook, after=kwargs["after"])
+    else:
+        add_hook_pre_reader(r, hook, before=add_info_holster)
+        add_info_holster = hook
+
     return hook
 
 # Filter for filtering out all read stories.
@@ -276,6 +282,46 @@ def yank(gui):
     else:
         gui.cfg.log("Yanked: %s" % gui.sel["item"]["title"])
 
+# Downloads image/link content into a specified directory using wget.
+#
+# Usage : reader_keys['w'] = wget_link("/path/to/downloads")
+
+def wget_link(path):
+    def do_wget(reader):
+        term = input.num_input(reader.cfg, "Link")
+        if not term:
+            return
+
+        try:
+            url = reader.links[term][1]
+        except:
+            reader.cfg.log("Invalid link.")
+            return
+
+        cmd = "wget -P \"" + path + "\" \"%u\""
+        utility.silentfork(cmd, url, 0, 0)
+
+    return do_wget
+
+# Highlights a word in the reader or main views
+#
+# Usage :
+#   r = get_default_renderer()
+#   add_hook_pre_reader(r, highlight_word("NASA"))
+#   add_hook_pre_story(r, highlight_word("never"))
+#
+#   Highlights the word "never" in the main view, and
+#   "NASA" in the reader. Extra arguments include flags
+#   to pass to the regex (defaults to re.I for ignorecase)
+#   and content, which defines the content in the item to be
+#   parsed.
+
+def highlight_word(word, flags=re.I, content="content"):
+    reg = re.compile(r"\b(" + re.escape(word) + r")\b", flags)
+    def hword(dict):
+        dict[content] = reg.sub(r"%R\1%r", dict[content])
+    return hword
+
 # Note: the following two hacks are for xterm and compatible
 # terminal emulators ([u]rxvt, eterm, aterm, etc.). These should
 # not be run in screen or standard linux terms because they'll
